@@ -144,6 +144,26 @@ MODULE-IDENTITY
             "".join(['REVISION "%s"\n' % x for x in self.getRevisions()]),
         )
 
+    ## compatibility with legacy code
+    def set_revisions(self, *args):
+        return self.setRevisions(args)
+
+    def set_last_updated(self, lastUpdated):
+        self.setLastUpdated(lastUpdated)
+        return self
+
+    def set_organization(self, organization):
+        self.setOrganization(organization)
+        return self
+
+    def set_contact_info(self, contactInfo):
+        self.setContactInfo(contactInfo)
+        return self
+
+    def set_description(self, description):
+        self.setDescription(description)
+        return self
+
 
 class ObjectIdentity(MibNode):
     status = "current"
@@ -181,6 +201,19 @@ OBJECT-IDENTITY
             self.getStatus(), self.getDescription(), self.getReference()
         )
 
+    ## compatibility with legacy code
+    def set_status(self, status):
+        self.setStatus(status)
+        return self
+
+    def set_description(self, description):
+        self.setDescription(description)
+        return self
+
+    def set_reference(self, reference):
+        self.setReference(reference)
+        return self
+
 
 # definition for objects
 
@@ -236,6 +269,18 @@ NOTIFICATION-TYPE
             self.getReference(),
         )
 
+    ## compatibility with legacy code
+    def set_objects(self, *args, **kwargs):
+        return self.setObjects(*args, **kwargs)
+
+    def set_status(self, status):
+        self.setStatus(status)
+        return self
+
+    def set_description(self, description):
+        self.setDescription(description)
+        return self
+
 
 class MibIdentifier(MibNode):
     @staticmethod
@@ -335,6 +380,29 @@ OBJECT-TYPE
             self.getReference(),
         )
 
+    ## compatibility with legacy code
+    def set_status(self, status):
+        self.setStatus(status)
+        return self
+
+    def set_description(self, description):
+        self.setDescription(description)
+        return self
+
+        ## compatibility with legacy code
+
+    def set_max_access(self, access):
+        self.setMaxAccess(access)
+        return self
+
+    def set_units(self, units):
+        self.setUnits(units)
+        return self
+
+    def set_reference(self, reference):
+        self.setReference(reference)
+        return self
+
 
 class MibTree(ObjectType):
     branchVersionId = 0  # cnanges on tree structure change
@@ -1524,6 +1592,18 @@ class MibTableRow(MibTree):
 
         return tuple(instNames)
 
+    ## compatibility with legacy code
+    def get_index_names(self):
+        return self.getIndexNames()
+
+    def set_index_names(self, *names):
+        self.setIndexNames(*names)
+        return self
+
+    def register_augmentions(self, *names):
+        self.registerAugmentions(*names)
+        return self
+
 
 class MibTable(MibTree):
     """MIB table. Manages a set of TableRow's"""
